#!/usr/bin/env python
import timeit
import sys
from nes import *

# # Small file
# original_file = "/gpfs/scratch/bsc32/bsc32538/mr_multiplyby/original_file/MONARCH_d01_2008123100.nc"
# Medium file
original_file = "/gpfs/scratch/bsc32/bsc32538/mr_multiplyby/original_file/MONARCH_d01_2021080212.nc"
# # Large file
# original_file = "/gpfs/scratch/bsc32/bsc32538/mr_multiplyby/original_file/MONARCH_d01_2017123000.nc"

st_time = timeit.default_timer()
# ===== Reading

nessy = RotatedNes(path=original_file)
nessy.keep_vars(['NO2', 'NO', 'O3', 'NO3'])

# ===== END Reading
spent_time = timeit.default_timer() - st_time
print("Init time {0:02d}:{1:02.3f} ({2:.3f}s/var)".format(
    int(spent_time // 60), spent_time - (int(spent_time // 60) * 60), spent_time / len(nessy.variables.keys())))
sys.stdout.flush()
# =====
st_time = timeit.default_timer()
# ===== Loading

nessy.load()

# ===== END Loading
spent_time = timeit.default_timer() - st_time
print("Loading time {min:02d}:{sec:02.3f} ({var:.3f}s/var)".format(
    min=int(spent_time // 60), sec=spent_time - (int(spent_time // 60) * 60),
    var=spent_time / len(nessy.variables.keys())))
sys.stdout.flush()
# =====
st_time = timeit.default_timer()
# ===== Parallel Write
nessy.to_netcdf('test_parallel.nc')
# ===== END Parallel Write
spent_time = timeit.default_timer() - st_time
print("Writing in parallel time {0:02d}:{1:02.3f} ({2:.3f}s)".format(
    int(spent_time // 60), spent_time - (int(spent_time // 60) * 60), spent_time / len(nessy.variables.keys())))
sys.stdout.flush()
# =====

st_time = timeit.default_timer()
# ===== Serial Write
nessy.to_netcdf('test_serial.nc', serial=True)
# ===== END Serial Write
spent_time = timeit.default_timer() - st_time
print("Writing in serial time {0:02d}:{1:02.3f} ({2:.3f}s)".format(
    int(spent_time // 60), spent_time - (int(spent_time // 60) * 60), spent_time / len(nessy.variables.keys())))
sys.stdout.flush()
